# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.constants import Basins, Basin
from earthdiagnostics.ocean.areamoc import AreaMoc
from mock import Mock, patch


class TestAreaMoc(TestCase):
    
    def setUp(self):
        self.data_manager = Mock()
        self.diags = Mock()
        self.basins = Mock()
        self.basins.Global = Basin('Global')
        self.basins.Atlantic = Basin('Atlantic')

        self.box = Box()
        self.box.min_lat = 0
        self.box.max_lat = 0
        self.box.min_depth = 0
        self.box.max_depth = 0

        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))
        self.psi = AreaMoc(self.data_manager, '20000101', 1, 1, self.basins.Atlantic, self.box)

    def fake_parse(self, value):
        if type(value) is Basin:
            return value
        if value == 'atl':
            value = 'Atlantic'
        else:
            value = 'Global'

        return Basin(value)

    @patch.object(Basins, 'parse', fake_parse)
    def test_generate_jobs(self):
        jobs = AreaMoc.generate_jobs(self.diags, ['diagnostic', '0', '0', '0', '0'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], AreaMoc(self.data_manager, '20010101', 0, 0, self.basins.Global, self.box))
        self.assertEqual(jobs[1], AreaMoc(self.data_manager, '20010101', 0, 1, self.basins.Global, self.box))

        jobs = AreaMoc.generate_jobs(self.diags, ['diagnostic', '0', '0', '0', '0', 'atl'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], AreaMoc(self.data_manager, '20010101', 0, 0, self.basins.Atlantic, self.box))
        self.assertEqual(jobs[1], AreaMoc(self.data_manager, '20010101', 0, 1, self.basins.Atlantic, self.box))

        with self.assertRaises(Exception):
            AreaMoc.generate_jobs(self.diags, ['diagnostic'])
        with self.assertRaises(Exception):
            AreaMoc.generate_jobs(self.diags, ['diagnostic', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEqual(str(self.psi), 'Area MOC Startdate: 20000101 Member: 1 Chunk: 1 Box: 0N0 '
                                         'Basin: Atlantic')
