# coding=utf-8
from unittest import TestCase

from earthdiagnostics.diagnostic import DiagnosticVariableOption, DiagnosticOptionError
from earthdiagnostics.box import Box
from earthdiagnostics.ocean.cutsection import CutSection
from mock import Mock, patch

from earthdiagnostics.modelingrealm import ModelingRealms


class TestCutSection(TestCase):

    def setUp(self):
        self.data_manager = Mock()
        self.diags = Mock()

        self.box = Box()
        self.box.min_lat = 0
        self.box.max_lat = 0
        self.box.min_lon = 0
        self.box.max_lon = 0

        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))
        self.psi = CutSection(self.data_manager, '20000101', 1, 1, ModelingRealms.atmos, 'var', True, 0)

    def fake_parse(self, value):
        if not value:
            raise DiagnosticOptionError
        return value

    @patch.object(DiagnosticVariableOption, 'parse', fake_parse)
    def test_generate_jobs(self):
        jobs = CutSection.generate_jobs(self.diags, ['diagnostic', 'var', 'true', '10'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], CutSection(self.data_manager, '20010101', 0, 0, ModelingRealms.ocean, 'var',
                                             True, 10))
        self.assertEqual(jobs[1], CutSection(self.data_manager, '20010101', 0, 1, ModelingRealms.ocean, 'var',
                                             True, 10))

        jobs = CutSection.generate_jobs(self.diags, ['diagnostic', 'var', 'false', '0', 'atmos'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], CutSection(self.data_manager, '20010101', 0, 0, ModelingRealms.atmos, 'var',
                                             False, 0))
        self.assertEqual(jobs[1], CutSection(self.data_manager, '20010101', 0, 1, ModelingRealms.atmos, 'var',
                                             False, 0))

        with self.assertRaises(DiagnosticOptionError):
            CutSection.generate_jobs(self.diags, ['diagnostic'])
        with self.assertRaises(DiagnosticOptionError):
            CutSection.generate_jobs(self.diags, ['diagnostic', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEqual(str(self.psi), 'Cut section Startdate: 20000101 Member: 1 Chunk: 1 Variable: atmos:var '
                                         'Zonal: True Value: 0')
