# coding=utf-8
from unittest import TestCase

from earthdiagnostics.ocean.rotation import Rotation
from earthdiagnostics.modelingrealm import ModelingRealms
from earthdiagnostics.diagnostic import DiagnosticOptionError, DiagnosticVariableOption
from mock import Mock, patch


class TestMixedLayerHeatContent(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))

        self.mixed = Rotation(self.data_manager, '20000101', 1, 1, ModelingRealms.ocean, 'varu', 'varv', 'exe')

    def fake_parse(self, value):
        if not value:
            raise DiagnosticOptionError
        return value

    @patch.object(DiagnosticVariableOption, 'parse', fake_parse)
    def test_generate_jobs(self):
        jobs = Rotation.generate_jobs(self.diags, ['diagnostic', 'ocean', 'varu', 'varv'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], Rotation(self.data_manager, '20010101', 0, 0, ModelingRealms.ocean, 'varu', 'varv',
                                           '/home/Earth/jvegas/pyCharm/cfutools/interpolation/rotateUVorca'))
        self.assertEqual(jobs[1], Rotation(self.data_manager, '20010101', 0, 1, ModelingRealms.ocean, 'varu', 'varv',
                                           '/home/Earth/jvegas/pyCharm/cfutools/interpolation/rotateUVorca'))

        jobs = Rotation.generate_jobs(self.diags, ['diagnostic', 'ocean', 'varu', 'varv', 'exe'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0],
                         Rotation(self.data_manager, '20010101', 0, 0, ModelingRealms.ocean, 'varu', 'varv', 'exe'))
        self.assertEqual(jobs[1],
                         Rotation(self.data_manager, '20010101', 0, 1, ModelingRealms.ocean, 'varu', 'varv', 'exe'))

        with self.assertRaises(Exception):
            Rotation.generate_jobs(self.diags, ['diagnostic', 'ocean', 'varu', 'varv', 'exe', 'extra'])

    def test_str(self):
        self.assertEqual(str(self.mixed), 'Rotate variables Startdate: 20000101 Member: 1 Chunk: 1 Variables: ocean:varu , ocean:varv')
