# coding=utf-8
from unittest import TestCase

from earthdiagnostics.diagnostic import DiagnosticVariableOption, DiagnosticOptionError
from earthdiagnostics.box import Box
from earthdiagnostics.ocean.verticalmean import VerticalMean
from mock import Mock, patch


class TestVerticalMean(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))

        self.box = Box()
        self.box.min_depth = 0
        self.box.max_depth = 100

        self.mixed = VerticalMean(self.data_manager, '20000101', 1, 1, 'var', self.box)

    def fake_parse(self, value):
        if not value:
            raise DiagnosticOptionError
        return value

    @patch.object(DiagnosticVariableOption, 'parse', fake_parse)
    def test_generate_jobs(self):
        jobs = VerticalMean.generate_jobs(self.diags, ['diagnostic', 'var', '0', '100'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], VerticalMean(self.data_manager, '20010101', 0, 0, 'var', self.box))
        self.assertEqual(jobs[1], VerticalMean(self.data_manager, '20010101', 0, 1, 'var', self.box))

        jobs = VerticalMean.generate_jobs(self.diags, ['diagnostic', 'var', '0'])
        box = Box()
        box.min_depth = 0
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], VerticalMean(self.data_manager, '20010101', 0, 0, 'var', box))
        self.assertEqual(jobs[1], VerticalMean(self.data_manager, '20010101', 0, 1, 'var', box))

        jobs = VerticalMean.generate_jobs(self.diags, ['diagnostic', 'var'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], VerticalMean(self.data_manager, '20010101', 0, 0, 'var', Box()))
        self.assertEqual(jobs[1], VerticalMean(self.data_manager, '20010101', 0, 1, 'var', Box()))

        with self.assertRaises(DiagnosticOptionError):
            VerticalMean.generate_jobs(self.diags, ['diagnostic'])

        with self.assertRaises(DiagnosticOptionError):
            VerticalMean.generate_jobs(self.diags, ['diagnostic', '0', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEqual(str(self.mixed), 'Vertical mean Startdate: 20000101 Member: 1 Chunk: 1 Variable: var '
                                           'Box: 0-100')
