# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.statistics.monthlypercentile import MonthlyPercentile
from mock import Mock

from earthdiagnostics.modelingrealm import ModelingRealms


class TestMonthlyPercentile(TestCase):

    def setUp(self):
        self.data_manager = Mock()
        self.diags = Mock()

        self.box = Box()
        self.box.min_lat = 0
        self.box.max_lat = 0
        self.box.min_lon = 0
        self.box.max_lon = 0

        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))
        self.diagnostic = MonthlyPercentile(self.data_manager, '20000101', 1, 1, ModelingRealms.ocean, 'var', [10, 90])

    def test_generate_jobs(self):
        jobs = MonthlyPercentile.generate_jobs(self.diags, ['monpercent', 'ocean', 'var', '10-90'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MonthlyPercentile(self.data_manager, '20010101', 0, 0, ModelingRealms.ocean, 'var',
                                                    [10, 90]))
        self.assertEqual(jobs[1], MonthlyPercentile(self.data_manager, '20010101', 0, 1, ModelingRealms.ocean, 'var',
                                                    [10, 90]))

        with self.assertRaises(Exception):
            MonthlyPercentile.generate_jobs(self.diags, ['monpercent'])
        with self.assertRaises(Exception):
            MonthlyPercentile.generate_jobs(self.diags, ['monpercent', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEqual(str(self.diagnostic), 'Monthly percentile Startdate: 20000101 Member: 1 Chunk: 1 '
                                                'Variable: ocean:var Percentiles: 10, 90')
