# coding=utf-8
from unittest import TestCase

from earthdiagnostics.frequency import Frequencies
from earthdiagnostics.modelingrealm import ModelingRealm, ModelingRealms


class TestModellingRealms(TestCase):

    def test_parse(self):
        self.assertEqual(ModelingRealms.parse('atmos'), ModelingRealms.atmos)
        self.assertEqual(ModelingRealms.parse('atmoschem'), ModelingRealms.atmosChem)
        self.assertEqual(ModelingRealms.parse('atmoSChem'), ModelingRealms.atmosChem)
        with self.assertRaises(ValueError):
            ModelingRealms.parse('badrealm')


class TestModellingRealm(TestCase):

    def setUp(self):
        self.realm = ModelingRealm('ocean')

    def test__repr__(self):
        self.assertEqual(str(self.realm), repr(self.realm))

    def test_constructor_fail_on_bad_realm(self):
        with self.assertRaises(ValueError):
            ModelingRealm('badrealm')

    def test_comparison(self):
        self.assertEqual(ModelingRealm('ocean'), self.realm)
        self.assertNotEqual(ModelingRealm('OCEAN'), self.realm)
        self.assertNotEqual(ModelingRealm('atmos'), self.realm)

    def test_get_omon(self):
        self.assertEqual(self.realm.get_table_name(Frequencies.monthly, 'specs'), 'Omon')

    def test_get_oimon(self):
        self.assertEqual(ModelingRealm('seaIce').get_table_name(Frequencies.monthly, 'specs'), 'OImon')

    def test_get_simon(self):
        self.assertEqual(ModelingRealm('seaIce').get_table_name(Frequencies.monthly, 'cmip6'), 'SImon')

    def test_get_limon(self):
        self.assertEqual(ModelingRealm('landIce').get_table_name(Frequencies.monthly, 'specs'), 'LImon')

    def test_get_day(self):
        self.assertEqual(ModelingRealm('atmos').get_table_name(Frequencies.daily, 'specs'), 'day')

    def test_get_6hrplev(self):
        self.assertEqual(ModelingRealm('atmos').get_table_name(Frequencies.six_hourly, 'specs'), '6hrPlev')




