# coding=utf-8
from unittest import TestCase
from earthdiagnostics.work_manager import Downloader, WorkManager
from earthdiagnostics.diagnostic import Diagnostic
from mock import Mock


class TestDownloader(TestCase):

    def setUp(self):
        self.downloader = Downloader()

    def test_start_and_stop(self):
        self.downloader.start()
        self.assertTrue(self.downloader._thread.is_alive())
        self.downloader.shutdown()
        self.assertFalse(self.downloader._thread.is_alive())

    def test_submit(self):
        datafile = Mock()
        self.downloader.submit(datafile)

    def test_download(self):
        datafile = Mock()
        self.downloader.submit(datafile)
        self.downloader.start()
        self.downloader.shutdown()

        datafile.download.assert_called_once()


class TestWorkManager(TestCase):


    def setUp(self):
        self.config = Mock()
        self.data_manager = Mock()
        self.work_manager = WorkManager(self.config, self.data_manager)

    def test_prepare_job_list(self):

        class Diag1(Diagnostic):
            alias = 'diag1'

            @classmethod
            def generate_jobs(cls, diags, options):
                cls.process_options(options, [])
                diag = Diag1(self.data_manager)
                diag.add_subjob(Diag1(self.data_manager))
                return (diag,)

        self.config.get_commands.return_value = ['diag1', 'baddiag', 'diag1,badoption']
        Diagnostic.register(Diag1)
        self.work_manager.prepare_job_list()
